package com.ruoyi.fire.mapper;

import java.util.List;
import com.ruoyi.fire.domain.FireFacilityReplacement;

/**
 * 消防设施更换记录Mapper接口
 * 
 * @author Junhau
 * @date 2025-07-17
 */
public interface FireFacilityReplacementMapper 
{
    /**
     * 查询消防设施更换记录
     * 
     * @param id 消防设施更换记录主键
     * @return 消防设施更换记录
     */
    public FireFacilityReplacement selectFireFacilityReplacementById(Long id);

    /**
     * 查询消防设施更换记录列表
     * 
     * @param fireFacilityReplacement 消防设施更换记录
     * @return 消防设施更换记录集合
     */
    public List<FireFacilityReplacement> selectFireFacilityReplacementList(FireFacilityReplacement fireFacilityReplacement);

    /**
     * 新增消防设施更换记录
     * 
     * @param fireFacilityReplacement 消防设施更换记录
     * @return 结果
     */
    public int insertFireFacilityReplacement(FireFacilityReplacement fireFacilityReplacement);

    /**
     * 修改消防设施更换记录
     * 
     * @param fireFacilityReplacement 消防设施更换记录
     * @return 结果
     */
    public int updateFireFacilityReplacement(FireFacilityReplacement fireFacilityReplacement);

    /**
     * 删除消防设施更换记录
     * 
     * @param id 消防设施更换记录主键
     * @return 结果
     */
    public int deleteFireFacilityReplacementById(Long id);

    /**
     * 批量删除消防设施更换记录
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteFireFacilityReplacementByIds(Long[] ids);
}
