package com.ruoyi.fire.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.fire.domain.FireFacilityReplacement;
import com.ruoyi.fire.service.IFireFacilityReplacementService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 消防设施更换记录Controller
 * 
 * @author Junhau
 * @date 2025-07-17
 */
@RestController
@RequestMapping("/fire_facility_replacement/replacement")
public class FireFacilityReplacementController extends BaseController
{
    @Autowired
    private IFireFacilityReplacementService fireFacilityReplacementService;

    /**
     * 查询消防设施更换记录列表
     */
    @PreAuthorize("@ss.hasPermi('fire_facility_replacement:replacement:list')")
    @GetMapping("/list")
    public TableDataInfo list(FireFacilityReplacement fireFacilityReplacement)
    {
        startPage();
        List<FireFacilityReplacement> list = fireFacilityReplacementService.selectFireFacilityReplacementList(fireFacilityReplacement);
        return getDataTable(list);
    }

    /**
     * 导出消防设施更换记录列表
     */
    @PreAuthorize("@ss.hasPermi('fire_facility_replacement:replacement:export')")
    @Log(title = "消防设施更换记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, FireFacilityReplacement fireFacilityReplacement)
    {
        List<FireFacilityReplacement> list = fireFacilityReplacementService.selectFireFacilityReplacementList(fireFacilityReplacement);
        ExcelUtil<FireFacilityReplacement> util = new ExcelUtil<FireFacilityReplacement>(FireFacilityReplacement.class);
        util.exportExcel(response, list, "消防设施更换记录数据");
    }

    /**
     * 获取消防设施更换记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('fire_facility_replacement:replacement:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(fireFacilityReplacementService.selectFireFacilityReplacementById(id));
    }

    /**
     * 新增消防设施更换记录
     */
    @PreAuthorize("@ss.hasPermi('fire_facility_replacement:replacement:add')")
    @Log(title = "消防设施更换记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody FireFacilityReplacement fireFacilityReplacement)
    {
        return toAjax(fireFacilityReplacementService.insertFireFacilityReplacement(fireFacilityReplacement));
    }

    /**
     * 修改消防设施更换记录
     */
    @PreAuthorize("@ss.hasPermi('fire_facility_replacement:replacement:edit')")
    @Log(title = "消防设施更换记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody FireFacilityReplacement fireFacilityReplacement)
    {
        return toAjax(fireFacilityReplacementService.updateFireFacilityReplacement(fireFacilityReplacement));
    }

    /**
     * 删除消防设施更换记录
     */
    @PreAuthorize("@ss.hasPermi('fire_facility_replacement:replacement:remove')")
    @Log(title = "消防设施更换记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(fireFacilityReplacementService.deleteFireFacilityReplacementByIds(ids));
    }
}
